TimeInterval

Struct TimeInterval 

pub struct TimeInterval {
    pub start: Duration,
    pub end: Duration,
}
Closed temporal interval $[start, end]$ used by STL temporal operators.

Both bounds are represented as Duration values and interpreted in the same logical time domain as incoming Step timestamps.

Fields

start: Duration

Lower bound of the interval.

end: Duration

Upper bound of the interval.